@@ -1,9 +1,9 @@
 __title__ = "python-olm"
 __description__ = ("python CFFI bindings for the olm "
                    "cryptographic ratchet library")
-__url__ = "https://github.com/poljar/python-olm"
-__version__ = "3.2.12"
+__url__ = "https://gitlab.matrix.org/matrix-org/olm/-/tree/master/python"
+__version__ = "3.2.15"
 __author__ = "Damir Jelić"
 __author_email__ = "poljar@termina.org.uk"
 __license__ = "Apache 2.0"
-__copyright__ = "Copyright 2018-2019 Damir Jelić"
+__copyright__ = "Copyright 2018-2019 Damir Jelić, 2019-2023 The Matrix.org Foundation C.I.C."
